Welcome to the OppiaMobile documentation — OppiaMobile 0.4.2 documentation

### Navigation

- index
- next |
- OppiaMobile 0.4.2 documentation »

# Welcome to the OppiaMobile documentation

OppiaMobile is the mobile learning platform from Digital Campus. This documentation details how to set up your own server and how you may make basic customisations.

Contents:

- Installation
- Installing on Amazon Web Services
- Installing VirtualBox Image
- Local Settings
- Upgrading
- REST API
- Utilities
- Customisation
- Visualizations
- Change Log
- Creating your course in Moodle
- Acknowledgements

### Navigation

- index
- next |
- OppiaMobile 0.4.2 documentation »